<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="de" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="67"/>
        <source>Behavior</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically save documents</source>
        <translation>Dokumente automatisch speichern</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Restore window geometry</source>
        <translation>Fenster-Zustand merken</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Use live preview by default</source>
        <translation>Benutze standardmäßig die Live-Vorschau</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Open external links in ReText window</source>
        <translation>Externe Verweise im ReText-Fenster öffnen</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Erweiterungen für Markdown-Syntax (durch Kommata getrennt)</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation>Aktiviere für Markdown synchrones Scrollen</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Highlight current line</source>
        <translation>Aktuelle Zeile hervorheben</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Show line numbers</source>
        <translation>Zeilennummern anzeigen</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tab key inserts spaces</source>
        <translation>Tabulator fügt Leerzeichen ein</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tabulation width</source>
        <translation>Tabulator-Breite</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Draw vertical line at column</source>
        <translation>Zeichne vertikale Linie in die Spalte</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Interface</source>
        <translation>Oberfläche</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Icon theme name</source>
        <translation>Symbolschema-Name</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Stylesheet file</source>
        <translation>Stilvorlage-Datei</translation>
    </message>
    <message>
        <location filename="config.py" line="103"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="34"/>
        <source>(none)</source>
        <translation>(keine)</translation>
    </message>
    <message>
        <location filename="config.py" line="41"/>
        <source>Select file to open</source>
        <translation>Zu öffnende Datei auswählen</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Eingabe der Lokalisierung (z.B.: de_DE)</translation>
    </message>
    <message>
        <location filename="dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>Als Standard setzen</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="fakevimeditor.py" line="64"/>
        <source>No write since last change (add ! to override)</source>
        <translation>Nichts geschrieben seit der letzten Änderung (! zum Überschreiben)</translation>
    </message>
    <message>
        <location filename="fakevimeditor.py" line="121"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="editor.py" line="285"/>
        <source>Save image</source>
        <translation>Speicher als Bild</translation>
    </message>
    <message>
        <location filename="editor.py" line="285"/>
        <source>Images (*.png *.jpg)</source>
        <translation>Bild (*.png *.jpg)</translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="tab.py" line="177"/>
        <source>New document</source>
        <translation>Neues Dokument</translation>
    </message>
    <message>
        <location filename="tab.py" line="182"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Dateiinhalte konnten nicht ausgewertet werden. Überprüfen Sie, ob die &lt;a href=&quot;%s&quot;&gt;notwendigen Module&lt;/a&gt; installiert sind!</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="81"/>
        <source>File toolbar</source>
        <translation>Datei-Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="window.py" line="83"/>
        <source>Edit toolbar</source>
        <translation>Bearbeiten-Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="window.py" line="85"/>
        <source>Search toolbar</source>
        <translation>Such-Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="window.py" line="89"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="window.py" line="92"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="window.py" line="95"/>
        <source>Set encoding</source>
        <translation>Zeichenkodierung festlegen</translation>
    </message>
    <message>
        <location filename="window.py" line="1044"/>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <location filename="window.py" line="101"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="window.py" line="105"/>
        <source>Save as</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <location filename="window.py" line="107"/>
        <source>Next tab</source>
        <translation>Nächster Reiter</translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Previous tab</source>
        <translation>Voriger Reiter</translation>
    </message>
    <message>
        <location filename="window.py" line="111"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="window.py" line="114"/>
        <source>Print preview</source>
        <translation>Druckvorschau</translation>
    </message>
    <message>
        <location filename="window.py" line="116"/>
        <source>View HTML code</source>
        <translation>HTML-Code anzeigen</translation>
    </message>
    <message>
        <location filename="window.py" line="117"/>
        <source>Change editor font</source>
        <translation>Schrift des Editors ändern</translation>
    </message>
    <message>
        <location filename="window.py" line="119"/>
        <source>Change preview font</source>
        <translation>Schrift der Vorschau ändern</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Find text</source>
        <translation>Suche</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="window.py" line="135"/>
        <source>Live preview</source>
        <translation>Live-Vorschau</translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>FakeVim mode</source>
        <translation>Pseudo-Vim-Modus</translation>
    </message>
    <message>
        <location filename="window.py" line="149"/>
        <source>Fullscreen mode</source>
        <translation>Vollbildmodus</translation>
    </message>
    <message>
        <location filename="window.py" line="553"/>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="window.py" line="159"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="window.py" line="162"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="window.py" line="164"/>
        <source>Redo</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="window.py" line="170"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="window.py" line="180"/>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="window.py" line="181"/>
        <source>Set locale</source>
        <translation>Spracheinstellung</translation>
    </message>
    <message>
        <location filename="window.py" line="182"/>
        <source>Use WebKit renderer</source>
        <translation>WebKit-Renderer benutzen</translation>
    </message>
    <message>
        <location filename="window.py" line="187"/>
        <source>Show directory</source>
        <translation>Verzeichnis anzeigen</translation>
    </message>
    <message>
        <location filename="window.py" line="188"/>
        <source>Next</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <location filename="window.py" line="190"/>
        <source>Previous</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location filename="window.py" line="192"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="window.py" line="195"/>
        <source>Get help online</source>
        <translation>Online Hilfe bekommen</translation>
    </message>
    <message>
        <location filename="window.py" line="196"/>
        <source>About ReText</source>
        <translation>Über ReText</translation>
    </message>
    <message>
        <location filename="window.py" line="199"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <location filename="window.py" line="216"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="window.py" line="218"/>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <location filename="window.py" line="230"/>
        <source>Symbols</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="window.py" line="235"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="window.py" line="236"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="window.py" line="237"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="window.py" line="240"/>
        <source>Open recent</source>
        <translation>Zuletzt geöffnet</translation>
    </message>
    <message>
        <location filename="window.py" line="252"/>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <location filename="window.py" line="273"/>
        <source>Spell check</source>
        <translation>Rechtschreibprüfung</translation>
    </message>
    <message>
        <location filename="window.py" line="281"/>
        <source>Default markup</source>
        <translation>Standard-Markup</translation>
    </message>
    <message>
        <location filename="window.py" line="284"/>
        <source>Formatting</source>
        <translation>Formatieren</translation>
    </message>
    <message>
        <location filename="window.py" line="321"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="window.py" line="323"/>
        <source>Case sensitively</source>
        <translation>Groß-/Kleinschreibung</translation>
    </message>
    <message>
        <location filename="window.py" line="458"/>
        <source>New document</source>
        <translation>Neues Dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="622"/>
        <source>Please, save the file somewhere.</source>
        <translation>Bitte die Datei irgendwo speichern.</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>Select one or several files to open</source>
        <translation>Eine oder mehrere Dateien zum Öffnen auswählen</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>Supported files</source>
        <translation>Unterstützte Dateien</translation>
    </message>
    <message>
        <location filename="window.py" line="738"/>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="776"/>
        <source>Select file encoding from the list:</source>
        <translation>Zeichenkodierung aus Liste auswählen:</translation>
    </message>
    <message>
        <location filename="window.py" line="797"/>
        <source>Plain text (*.txt)</source>
        <translation>Klartext (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="800"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s-Dateien</translation>
    </message>
    <message>
        <location filename="window.py" line="867"/>
        <source>Save file</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <location filename="window.py" line="821"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Speichern ist nicht möglich, Datei ist schreibgeschützt.</translation>
    </message>
    <message>
        <location filename="window.py" line="857"/>
        <source>Export document to ODT</source>
        <translation>Dokument in ODT exportieren</translation>
    </message>
    <message>
        <location filename="window.py" line="857"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument-Dateien (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="867"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML-Dateien (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="888"/>
        <source>Export document to PDF</source>
        <translation>Dokument in PDF exportieren</translation>
    </message>
    <message>
        <location filename="window.py" line="888"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF-Dateien (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="908"/>
        <source>Print document</source>
        <translation>Dokument drucken</translation>
    </message>
    <message>
        <location filename="window.py" line="932"/>
        <source>Export document</source>
        <translation>Dokument exportieren</translation>
    </message>
    <message>
        <location filename="window.py" line="953"/>
        <source>Failed to execute the command:</source>
        <translation>Ausführung des Befehls fehlgeschlagen:</translation>
    </message>
    <message>
        <location filename="window.py" line="987"/>
        <source>Alt text</source>
        <translation>Alt-Text</translation>
    </message>
    <message>
        <location filename="window.py" line="988"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="window.py" line="988"/>
        <source>Link text</source>
        <translation>Linktext</translation>
    </message>
    <message>
        <location filename="window.py" line="1028"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>Diese Datei wurde durch eine andere Anwendung gelöscht.
Bitte sichern Sie die Datei vor dem Beenden.</translation>
    </message>
    <message>
        <location filename="window.py" line="1035"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>Dieses Dokument wurde durch eine andere Anwendung geändert.
Wollen Sie die Datei neu laden (wobei alle Ihre Änderungen
verworfen werden)?</translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>Wenn Sie die Datei nicht neu laden, wird das automatische Speichern für diese Sitzung deaktiviert, um Datenverlust zu vermeiden. </translation>
    </message>
    <message>
        <location filename="window.py" line="1064"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Das Dokument wurde verändert.
Sollen die Änderungen gespeichert werden?</translation>
    </message>
    <message>
        <location filename="window.py" line="1089"/>
        <source>HTML code</source>
        <translation>HTML-Code</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>ReText %s (mit PyMarkups %s)</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Einfacher aber mächtiger Editor für Markdown and reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Website</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Markdown syntax</source>
        <translation>Markdown-Syntax</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText-Syntax</translation>
    </message>
    <message>
        <location filename="window.py" line="140"/>
        <source>Table editing mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
